#include "read_energ_data.i"

func prep_arf( fmodel, effa_file, fullarfname, aps= )
/* DOCUMENT prep_arf, fmodel, effa_file, fullarfname, aps=

   Reads the effective area file: effa_file and produces an ARF
   file in PHAII format that is output in 'fullarfname'. The low energy
   transmission is multiplied on the table.

   If the 'fullarfname' string contains an 'X' (like "crab22X_phaii.arf")
   it will be replaced with 'A' for fmodel==2 and with 'B' for fmodel==1.
   Otherwise it will be used as is.

   2013-01-04/NJW based on 'prep_spec.i', 2013-03-11 updated with 'aps'
*/
{

   //+ if( !strpos(fullarfname,"X") ) error,"No X in fullarfname";

   if( fmodel == 1 ) {
      letter = "B";
      mstr = "FM1";
   } else {
      letter = "A";
      mstr = "FM2";
   }
   instrume = "FPM" + letter;
   arfname = strstrrepl( fullarfname, "X", letter );
   telescop = "NuSTAR";

  /*
   *    Construct the ARF from the optic effective area and the
   *    thermal foil absorption
   */

   effa = read_effa(effa_file);
   ener = *effa.ener;
   eff_area = *effa.area;

   tr = read_energ_data("transmis_bemli.fits","transmis");
   arf = tr.data * interp(eff_area,ener,tr.el);

   kwds_init;
   if( strlen(effa_file) > 60 ) {
      kwds_setlongstr,"EFFAFILE", effa_file,"Eff area file";
   } else kwds_set,"EFFAFILE", effa_file,"Eff area file";

   if( !is_void(aps) ) {
      if( !file_test(aps) ) error,"Did not find "+aps;
      apscor = read_energ_data( aps, "specresp" );
      arf *= interp(apscor.data, apscor.el, tr.el );
      kwds_setlongstr,"APSCOR", aps,"Aperture stop correction table";
   }

   arf2phaii, arfname, arf, tr.elo, tr.ehi, extname="SPECRESP", \
      instrume=instrume, telescop="NuSTAR",nokwdsinit=1;
   write,"Wrote "+arfname;
}
